# lcfm-shapefiles

Python wrapper around shapefiles used for the LCFM project.

## Installation

```
pip install --index https://artifactory.vgt.vito.be/artifactory/api/pypi/python-packages/simple lcfm-shapefiles --upgrade
```

## Usage

```python
import lcfm_shapefiles import list_filepaths, get_filepath
import geopandas as gpd

# List out all available files; you can index this list to get a path
lcfm_shapefiles.list_filepaths()

# Get path a specific file
fp = lcfm_shapefiles.get_filepath("LCFM_1p_S2-tiles.fgb")

# Import fgb into a geopandas data frame
gdf = gpd.read_file(fp)
```

## Develop

```
# Build venv
uv sync

# Run tests
uv run pytest

# Build and publish
uv build
uv publish --publish-url https://artifactory.vgt.vito.be/artifactory/api/pypi/python-packages-public/
```

## CI/CD (TODO)

`lcfm-shapefiles` has a [corresponding Jenkins job](https://www.youtube.com/watch?v=dQw4w9WgXcQ) that builds branches (automatic) and tags (needs a manual 'Build Now'):

- Builds Docker image: uv, package dependencies, package itself (including binaries).
- Tags are built and published to Marvin Pypi Artifactory.

To release a new version:

- Increment the version in `pyproject.toml` in line with [semver](https://semver.org/)
- `uv sync` to update the `uv.lock` file (this is required)
- `git commit -m 'bump version'`
- `git tag x.y.z`
- `git push --tags origin main`
- On Jenkins, to the Tags tab of the job, and click "Build Now".
